@@ -1,6 +1,7 @@
 /* Contributed by Nicola Pero - Fri Mar  9 21:35:47 CET 2001 */
-#include <objc/objc.h>
-#include <objc/Protocol.h>
+
+#include <stdlib.h>
+#include "../../objc-obj-c++-shared/Protocol1.h"
 
 /* Test defining a protocol, and accessing it using @protocol */
 
@@ -15,7 +16,11 @@ int main (void)
 {
   Protocol *protocol = @protocol (Evaluating);
 
+#ifdef NEXT_OBJC_USE_NEW_INTERFACE
+  if (strcmp (protocol_getName(protocol), "Evaluating"))
+#else
   if (strcmp ([protocol name], "Evaluating"))
+#endif
     {
       abort ();
     }
